pychemia.code.abinit.task package
=================================

.. automodule:: pychemia.code.abinit.task
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.code.abinit.task.relax module
--------------------------------------

.. automodule:: pychemia.code.abinit.task.relax
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.abinit.task.static module
---------------------------------------

.. automodule:: pychemia.code.abinit.task.static
    :members:
    :undoc-members:
    :show-inheritance:


